@@ -1,3 +1,4 @@
+import asyncio
 from enum import Enum
 from typing import Optional
 
@@ -6,8 +7,9 @@ from typer import Argument, Exit, Option, Typer, echo
 
 from weather_command._builder import show_current, show_daily, show_hourly
 from weather_command._cache import Cache
+from weather_command._tui import WeatherApp
 
-__version__ = "2.1.4"
+__version__ = "3.0.0"
 
 install()
 app = Typer()
@@ -31,7 +33,7 @@ def version_callback(value: bool) -> None:
 
 
 @app.command()
-def main(
+def cli(
     how: How = Argument(
         "city",
         help="How to get the weather.",
@@ -73,15 +75,9 @@ def main(
     terminal_width: Optional[int] = Option(
         None, help="Allows for overriding the default terminal width."
     ),
-    version: Optional[bool] = Option(
-        None,
-        "--version",
-        "-v",
-        callback=version_callback,
-        is_eager=True,
-        help="Show the installed weather command version",
-    ),
 ) -> None:
+    """Run in CLI mode."""
+
     if clear_cache:
         cache = Cache()
         cache.clear()
@@ -89,39 +85,114 @@ def main(
     units = "imperial" if imperial else "metric"
 
     if forecast_type == "current":
-        show_current(
-            how=how,
-            city_zip=city_zip,
-            units=units,
-            state_code=state_code,
-            country_code=country_code,
-            am_pm=am_pm,
-            temp_only=temp_only,
-            terminal_width=terminal_width,
+        asyncio.run(
+            show_current(
+                how=how,
+                city_zip=city_zip,
+                units=units,
+                state_code=state_code,
+                country_code=country_code,
+                am_pm=am_pm,
+                temp_only=temp_only,
+                terminal_width=terminal_width,
+            )
         )
     elif forecast_type == "daily":
-        show_daily(
-            how=how,
-            city_zip=city_zip,
-            units=units,
-            state_code=state_code,
-            country_code=country_code,
-            am_pm=am_pm,
-            temp_only=temp_only,
-            terminal_width=terminal_width,
+        asyncio.run(
+            show_daily(
+                how=how,
+                city_zip=city_zip,
+                units=units,
+                state_code=state_code,
+                country_code=country_code,
+                am_pm=am_pm,
+                temp_only=temp_only,
+                terminal_width=terminal_width,
+            )
         )
     elif forecast_type == "hourly":
-        show_hourly(
-            how=how,
-            city_zip=city_zip,
-            units=units,
-            state_code=state_code,
-            country_code=country_code,
-            am_pm=am_pm,
-            temp_only=temp_only,
-            terminal_width=terminal_width,
+        asyncio.run(
+            show_hourly(
+                how=how,
+                city_zip=city_zip,
+                units=units,
+                state_code=state_code,
+                country_code=country_code,
+                am_pm=am_pm,
+                temp_only=temp_only,
+                terminal_width=terminal_width,
+            )
         )
 
 
+@app.callback(invoke_without_command=True)
+def main(
+    version: Optional[bool] = Option(
+        None,
+        "--version",
+        "-v",
+        is_eager=True,
+        help="Show the installed version",
+    ),
+) -> None:
+    if version:
+        echo(__version__)
+        raise Exit()
+
+
+@app.command()
+def tui(
+    how: How = Argument(
+        "city",
+        help="How to get the weather.",
+    ),
+    city_zip: str = Argument(
+        ...,
+        help="The name of the city or zip code for which the weather should be retrieved. If the first argument is 'city' this should be the name of the city, or if 'zip' it should be the zip code.",
+    ),
+    state_code: Optional[str] = Option(
+        None, "--state-code", "-s", help="The name of the state where the city is located."
+    ),
+    country_code: Optional[str] = Option(
+        None,
+        "--country-code",
+        "-c",
+        help="The country code where the city is located.",
+    ),
+    imperial: bool = Option(
+        False,
+        "--imperial",
+        "-i",
+        help="If this flag is used the units will be imperial, otherwise units will be metric.",
+    ),
+    am_pm: bool = Option(
+        False,
+        "--am-pm",
+        help="If this flag is set the times will be displayed in 12 hour format, otherwise times will be 24 hour format.",
+    ),
+    forecast_type: ForecastType = Option(
+        ForecastType.CURRENT,
+        "--forecast-type",
+        "-f",
+        help="The type of forecast to display.",
+    ),
+    clear_cache: bool = Option(False, help="Clear the cache data before running."),
+) -> None:
+    """Run in TUI mode."""
+
+    if clear_cache:
+        cache = Cache()
+        cache.clear()
+
+    WeatherApp.how = how
+    WeatherApp.city_zip = city_zip
+    WeatherApp.state = state_code
+    WeatherApp.country = country_code
+    WeatherApp.forecast_type = forecast_type
+    WeatherApp.units = "imperial" if imperial else "metric"
+    WeatherApp.am_pm = am_pm
+    WeatherApp.run()
+
+
 if __name__ == "__main__":
     app()
